TestableRenderController class
Controller that is used to provide information for the Testable. This includes information such as what gestures to respond to as well as how to render the global and / or individual overlays.
Constructors
- TestableRenderController({String debugLabel = 'custom', Color flashColor = const Color(0x88FFEB3B), int flashCount = 3, Duration flashDuration = const Duration(milliseconds: 100), TestableGestures? gestures, WidgetBuilder? globalOverlayBuilder, Color? overlayColor, bool showGlobalOverlay = false, bool testWidgetsEnabled = kDebugMode == true, WidgetOverlayBuilder? widgetOverlayBuilder})
Properties
- debugLabel → String
-
final
- flashColor → Color
-
no setter
- flashCount → int
-
no setter
- flashDuration → Duration
-
no setter
- gestures ↔ TestableGestures
-
getter/setter pair
- globalOverlayBuilder ↔ WidgetBuilder
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- overlayColor ↔ Color?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGlobalOverlay ↔ bool
-
getter/setter pair
-
stream
→ Stream<
void> ? -
no setter
- testWidgetsEnabled ↔ bool
-
getter/setter pair
- widgetOverlayBuilder ↔ WidgetOverlayBuilder
-
getter/setter pair
Methods
-
dispose(
) → void - Disposes the controller.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
borderGlobalOverlay(
{Color? color, double radius = 4.0}) → WidgetBuilder -
A global overlay that renders with a thin border around the entire
Testable widget using the given
colorand borderradius. -
fullGlobalOverlay(
{Color? color, double opacity = 0.1}) → WidgetBuilder -
A global overlay that renders with a solid
colorwith a givenopacityover the entire Testable widget. -
iconWidgetOverlay(
{Color? color, IconData? icon, double radius = 0.0}) → WidgetOverlayBuilder -
An individual overlay for a Testable widget that renders with a given
colorand centerediconusing a borderradius. -
idWidgetOverlay(
{Color? color, Color textColor = Colors.white, double radius = 0.0}) → WidgetOverlayBuilder -
An individual overlay for a Testable widget that renders with the given
colorand borderradius. This will render the current status text from the active TestRunner in the center of the widget. -
of(
BuildContext context) → TestableRenderController - Returns either the TestableRenderController from an ancestor TestRunner instance, or this will return the default controller if no TestRunner is available.